==> node-jasmine_4.0.2+~cs7.10.3.orig-jasmine-core.tar.gz: jasmine-4.0.0/spec/helpers/integrationMatchers.js <==
(function(env) {
  env.registerIntegrationMatchers = function() {
    jasmine.addMatchers({
      toHaveFailedExpectationsForRunnable: function() {
        return {
          compare: function(actual, fullName, expectedFailures) {
            var foundRunnable = false,
              expectations = true,
              foundFailures = [];
            for (var i = 0; i < actual.calls.count(); i++) {
              var args = actual.calls.argsFor(i)[0];

              if (args.fullName === fullName) {
                foundRunnable = true;

                for (var j = 0; j < args.failedExpectations.length; j++) {
                  foundFailures.push(args.failedExpectations[j].message);
                }

                for (var j = 0; j < expectedFailures.length; j++) {
                  var failure = foundFailures[j];
                  var expectedFailure = expectedFailures[j];

                  if (
                    Object.prototype.toString.call(expectedFailure) ===
                    '[object RegExp]'
                  ) {
                    expectations =
                      expectations && expectedFailure.test(failure);
                  } else {
                    expectations = expectations && failure === expectedFailure;
                  }
                }
                break;
              }
            }

            return {
              pass: foundRunnable && expectations,
              message: !foundRunnable
                ? 'The runnable "' + fullName + '" never finished'
                : 'Expected runnable "' +
                  fullName +
                  '" to have failures ' +
                  jasmine.basicPrettyPrinter_(expectedFailures) +
                  ' but it had ' +
                  jasmine.basicPrettyPrinter_(foundFailures)
            };
          }
        };
      }
    });
  };
})(jasmine.getEnv());

==> node-jasmine_4.5.0+~cs8.8.0.orig-jasmine-core.tar.gz: jasmine-4.5.0/spec/helpers/integrationMatchers.js <==
(function(env) {
  env.registerIntegrationMatchers = function() {
    jasmine.addMatchers({
      toHaveFailedExpectationsForRunnable: function() {
        return {
          compare: function(actual, fullName, expectedFailures) {
            let foundRunnable = false,
              expectations = true,
              foundFailures = [];
            for (let i = 0; i < actual.calls.count(); i++) {
              const args = actual.calls.argsFor(i)[0];

              if (args.fullName === fullName) {
                foundRunnable = true;

                for (let j = 0; j < args.failedExpectations.length; j++) {
                  foundFailures.push(args.failedExpectations[j].message);
                }

                for (let j = 0; j < expectedFailures.length; j++) {
                  const failure = foundFailures[j];
                  const expectedFailure = expectedFailures[j];

                  if (
                    Object.prototype.toString.call(expectedFailure) ===
                    '[object RegExp]'
                  ) {
                    expectations =
                      expectations && expectedFailure.test(failure);
                  } else {
                    expectations = expectations && failure === expectedFailure;
                  }
                }
                break;
              }
            }

            return {
              pass: foundRunnable && expectations,
              message: !foundRunnable
                ? 'The runnable "' + fullName + '" never finished'
                : 'Expected runnable "' +
                  fullName +
                  '" to have failures ' +
                  jasmine.basicPrettyPrinter_(expectedFailures) +
                  ' but it had ' +
                  jasmine.basicPrettyPrinter_(foundFailures)
            };
          }
        };
      }
    });
  };
})(jasmine.getEnv());
